You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by sz...@apache.org on 2005/10/08 13:41:03 UTC

svn commit: r307286 - in /directory/testsuite/trunk/ldaptests/src/main/java/org/apache/ldap/testsuite/ldaptests/jndi/ops/extended: AllTests.java UnknownExtendedOperationTest.java

Author: szoerner
Date: Sat Oct  8 04:40:58 2005
New Revision: 307286

URL: http://svn.apache.org/viewcvs?rev=307286&view=rev
Log:
Add missing and improve existing javadocs of test cases. 

Modified:
    directory/testsuite/trunk/ldaptests/src/main/java/org/apache/ldap/testsuite/ldaptests/jndi/ops/extended/AllTests.java
    directory/testsuite/trunk/ldaptests/src/main/java/org/apache/ldap/testsuite/ldaptests/jndi/ops/extended/UnknownExtendedOperationTest.java

Modified: directory/testsuite/trunk/ldaptests/src/main/java/org/apache/ldap/testsuite/ldaptests/jndi/ops/extended/AllTests.java
URL: http://svn.apache.org/viewcvs/directory/testsuite/trunk/ldaptests/src/main/java/org/apache/ldap/testsuite/ldaptests/jndi/ops/extended/AllTests.java?rev=307286&r1=307285&r2=307286&view=diff
==============================================================================
--- directory/testsuite/trunk/ldaptests/src/main/java/org/apache/ldap/testsuite/ldaptests/jndi/ops/extended/AllTests.java (original)
+++ directory/testsuite/trunk/ldaptests/src/main/java/org/apache/ldap/testsuite/ldaptests/jndi/ops/extended/AllTests.java Sat Oct  8 04:40:58 2005
@@ -19,6 +19,9 @@
 import junit.framework.TestSuite;
 
 /**
+ * Contains the test classes for the LDAP extended operation executed via JNDI.
+ * It is used to form the complete suite into a structure.
+ * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev: $
  */
@@ -28,7 +31,6 @@
     public static TestSuite suite()
     {
         TestSuite suite = new TestSuite("Extended");
-
         suite.addTestSuite(UnknownExtendedOperationTest.class);
 
         return suite;

Modified: directory/testsuite/trunk/ldaptests/src/main/java/org/apache/ldap/testsuite/ldaptests/jndi/ops/extended/UnknownExtendedOperationTest.java
URL: http://svn.apache.org/viewcvs/directory/testsuite/trunk/ldaptests/src/main/java/org/apache/ldap/testsuite/ldaptests/jndi/ops/extended/UnknownExtendedOperationTest.java?rev=307286&r1=307285&r2=307286&view=diff
==============================================================================
--- directory/testsuite/trunk/ldaptests/src/main/java/org/apache/ldap/testsuite/ldaptests/jndi/ops/extended/UnknownExtendedOperationTest.java (original)
+++ directory/testsuite/trunk/ldaptests/src/main/java/org/apache/ldap/testsuite/ldaptests/jndi/ops/extended/UnknownExtendedOperationTest.java Sat Oct  8 04:40:58 2005
@@ -23,7 +23,9 @@
 import javax.naming.ldap.LdapContext;
 
 /**
- * Check the behaviour of the server for an unknown extended operation.
+ * Checks the behaviour of the server for an unknown extended operation. Because
+ * extended operations are server dependent, this is the only test case for them
+ * within the suite.
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev: $
@@ -32,7 +34,8 @@
 {
 
     /**
-     * Calls an extended exception, which does not exist. Expected behaviour is
+     * Checks the behaviour of the server for an unknown extended operation. It
+     * calls an extended exception, which does not exist. Expected behaviour is
      * a CommunicationException.
      * 
      * @throws NamingException
@@ -50,16 +53,24 @@
     }
 
     /**
      * Class for the request of an extended operation which does not exist.
      */
     private class UnknownExtendedOperationRequest implements ExtendedRequest
     {
 
         private static final long serialVersionUID = 1L;
 
+        public static final String OID = "1.1";
+
+        /**
+         * Returns the OID of the extended operation.
+         * 
+         * @return the OID
+         */
         public String getID()
         {
-            return "1.1";
+            return OID;
         }
 
         public byte[] getEncodedValue()
@@ -50,16 +53,24 @@
 
     /**
-     * Class for the request of an extended operation which does not exist.
+     * Class for the request of an extended operation which does not exist. This
+     * is forced by using OID "1.1".
      */
     private class UnknownExtendedOperationRequest implements ExtendedRequest